"""
The official Python library for The Rock Trading exchange API
"""

__version__ = '1.1.2'

from .client_sync import ClientSync as Client
from .client_sync import ClientSync
from .client_async import ClientAsync
